clear all;     % run following codes to get table A2
clc;

tic       % the simulation will cost about 790 sec

data1=xlsread('repdata.xlsx');

 
% Macroeconomic indicators
gdp=data1(:,1);
consumption=data1(:,2);
unemployment=data1(:,3);
investment=data1(:,4);

%Financing indicators
loan_1y=data1(:,5);
loan_1_5y=data1(:,6);
bond_3m=data1(:,7);
bond_1y=data1(:,8);

%Credit and funding indicators
demand_all=data1(:,9);
demand_L=data1(:,10);
demand_M=data1(:,11);
demand_S=data1(:,12);
wmp_v=data1(:,13);
trustloan=data1(:,14);

%Financial intermediary indicators
lev_b=data1(:,15);
lev_s=data1(:,16);
lev_t=data1(:,17);
roa_b=data1(:,18);
roa_s=data1(:,19);
roa_t=data1(:,20);

%Independent indicators
ndp=data1(:,21);
dp=data1(:,22);
ts=data1(:,23);
fr=data1(:,24);
gz=data1(:,25);
gz_p=data1(:,26);

%Other indicators
spread=data1(:,27);
ndp_iv=data1(:,28);

% Note: Only parts of of variables above are used in the tests of Table A2

%Panel A of Table A2 

    
    yt=gdp;
    
    lag=1;
    
    lagy=[];
    
    simu_round=5000;                              % set total rounds of simulation  as 5000
    simu_bottom=simu_round*0.25;       % report the bottom quartile case of simulation
    
    for i=1:lag
        
        
     lagy=[lagy,yt(i:size(yt,1)-lag-1+i)];
        
    end
    

    xt=[lagy,[ts(lag:size(yt,1)-lag-1+i,1),fr(lag:size(yt,1)-lag-1+i,1),dp(lag:size(yt,1)-lag-1+i,1),ndp(lag:size(yt,1)-lag-1+i,1)]];

    yt1=yt(lag+1:end,1);

    xt1=xt;    

sta=regstats(yt1,xt1);


res=sta.r;                % get residual of regression

est_yt=yt1-sta.r;     % get estimated dependent variable of regression


simu_all=[];

for boot=1:simu_round
    
     rd_index= randperm(size(res, 1)); 
     rdres = res(rd_index, :);                     % generate random residual
     
     rd_yt=est_yt+rdres;                           % get new dependent variable with estimated dependent variable and random residual
    
     
      sta_rd=regstats(rd_yt,xt1);
     
     adjr2=sta_rd.adjrsquare;                  % get adjusted R-square 
     
    maxLag = floor(4*(35/100)^(2/9));

    [~,se,coeff] = hac(xt1,rd_yt,'bandwidth',maxLag+1,'display','off');              % get Newey and West (1987) corrected t-values


    t_nw=coeff./se;

    res_1_round=[coeff(end-3,1);t_nw(end-3,1);coeff(end-2,1);t_nw(end-2,1);
     coeff(end-1,1);t_nw(end-1,1);coeff(end,1);t_nw(end,1);adjr2];                            % get the results of one round simulation
   
     
     simu_all=[simu_all,res_1_round];                                                                % record the results of 5000 round simulations
     
    
end

simu_all=simu_all';

simu_all=sortrows(simu_all,size(simu_all,2)-1);                 % sort 5000 results based on the t-value of NDP

simu_res1=simu_all(simu_bottom,:);                                  % show the  bottom quartile case of NDP

simu_res1=simu_res1';


%%%%%%%%%%%%%%%%%%%%%%%%%

yt=consumption;
    
    lag=1;
    
    lagy=[];
    
    simu_round=5000;
    simu_bottom=simu_round*0.25;
    
    for i=1:lag
        
        
     lagy=[lagy,yt(i:size(yt,1)-lag-1+i)];
        
    end
    

    xt=[lagy,[ts(lag:size(yt,1)-lag-1+i,1),fr(lag:size(yt,1)-lag-1+i,1),dp(lag:size(yt,1)-lag-1+i,1),ndp(lag:size(yt,1)-lag-1+i,1)]];

    yt1=yt(lag+1:end,1);

    xt1=xt;    

sta=regstats(yt1,xt1);


res=sta.r;

est_yt=yt1-sta.r;


simu_all=[];

for boot=1:simu_round
    
     rd_index= randperm(size(res, 1)); 
     rdres = res(rd_index, :);
     
     rd_yt=est_yt+rdres;
    
     
      sta_rd=regstats(rd_yt,xt1);
     
     adjr2=sta_rd.adjrsquare;
     
    maxLag = floor(4*(35/100)^(2/9));

    [~,se,coeff] = hac(xt1,rd_yt,'bandwidth',maxLag+1,'display','off');


    t_nw=coeff./se;

    res_1_round=[coeff(end-3,1);t_nw(end-3,1);coeff(end-2,1);t_nw(end-2,1);
     coeff(end-1,1);t_nw(end-1,1);coeff(end,1);t_nw(end,1);adjr2];
   
     
     simu_all=[simu_all,res_1_round];
     
    
end

simu_all=simu_all';

simu_all=sortrows(simu_all,size(simu_all,2)-1);

simu_res2=simu_all(simu_bottom,:);

simu_res2=simu_res2';

%%%%%%%%%%%%%%%%%%%

yt=unemployment;
    
    lag=1;
    
    lagy=[];
    
    simu_round=5000;
    simu_bottom=simu_round*0.75;

    %The t-value will be sorted from small to large. As the coefficent of
    %NDP to unemployment is negative, we report the top quartile result of simulation (the case of worst quartile).
    
    for i=1:lag
           
     lagy=[lagy,yt(i:size(yt,1)-lag-1+i)];
        
    end
    

    xt=[lagy,[ts(lag:size(yt,1)-lag-1+i,1),fr(lag:size(yt,1)-lag-1+i,1),dp(lag:size(yt,1)-lag-1+i,1),ndp(lag:size(yt,1)-lag-1+i,1)]];

    yt1=yt(lag+1:end,1);

    xt1=xt;    

sta=regstats(yt1,xt1);


res=sta.r;

est_yt=yt1-sta.r;


simu_all=[];

for boot=1:simu_round
    
     rd_index= randperm(size(res, 1)); 
     rdres = res(rd_index, :);
     
     rd_yt=est_yt+rdres;
    
     
      sta_rd=regstats(rd_yt,xt1);
     
     adjr2=sta_rd.adjrsquare;
     
    maxLag = floor(4*(35/100)^(2/9));

    [~,se,coeff] = hac(xt1,rd_yt,'bandwidth',maxLag+1,'display','off');


    t_nw=coeff./se;

    res_1_round=[coeff(end-3,1);t_nw(end-3,1);coeff(end-2,1);t_nw(end-2,1);
     coeff(end-1,1);t_nw(end-1,1);coeff(end,1);t_nw(end,1);adjr2];
   
     
     simu_all=[simu_all,res_1_round];
     
    
end

simu_all=simu_all';

simu_all=sortrows(simu_all,size(simu_all,2)-1);

simu_res3=simu_all(simu_bottom,:);

simu_res3=simu_res3';

%%%%%%%%%%%%%%%%%%%


yt=investment;
    
    lag=1;
    
    lagy=[];
    
    simu_round=5000;
    simu_bottom=simu_round*0.25;
    
    for i=1:lag
           
     lagy=[lagy,yt(i:size(yt,1)-lag-1+i)];
        
    end
    

    xt=[lagy,[ts(lag:size(yt,1)-lag-1+i,1),fr(lag:size(yt,1)-lag-1+i,1),dp(lag:size(yt,1)-lag-1+i,1),ndp(lag:size(yt,1)-lag-1+i,1)]];

    yt1=yt(lag+1:end,1);

    xt1=xt;    

sta=regstats(yt1,xt1);


res=sta.r;

est_yt=yt1-sta.r;


simu_all=[];

for boot=1:simu_round
    
     rd_index= randperm(size(res, 1)); 
     rdres = res(rd_index, :);
     
     rd_yt=est_yt+rdres;
    
     
      sta_rd=regstats(rd_yt,xt1);
     
     adjr2=sta_rd.adjrsquare;
     
    maxLag = floor(4*(35/100)^(2/9));

    [~,se,coeff] = hac(xt1,rd_yt,'bandwidth',maxLag+1,'display','off');


    t_nw=coeff./se;

    res_1_round=[coeff(end-3,1);t_nw(end-3,1);coeff(end-2,1);t_nw(end-2,1);
     coeff(end-1,1);t_nw(end-1,1);coeff(end,1);t_nw(end,1);adjr2];
   
     
     simu_all=[simu_all,res_1_round];
     
    
end

simu_all=simu_all';

simu_all=sortrows(simu_all,size(simu_all,2)-1);

simu_res4=simu_all(simu_bottom,:);

simu_res4=simu_res4';



simu_res_final_A=[simu_res1,simu_res2,simu_res3,simu_res4];               % combine all results to get panel A of table A2

%%%%%%%%%%%%%%%%%%%%

%Panel B of Table A2

%%%%%%%%%%%%%%%%%%%%

yt=bond_3m;
    
    lag=1;
    
    lagy=[];
    
    simu_round=5000;
    simu_bottom=simu_round*0.75;
    
    for i=1:lag
        
        
     lagy=[lagy,yt(i:size(yt,1)-lag-1+i)];
        
    end
    

    xt=[lagy,[ts(lag:size(yt,1)-lag-1+i,1),fr(lag:size(yt,1)-lag-1+i,1),dp(lag:size(yt,1)-lag-1+i,1),ndp(lag:size(yt,1)-lag-1+i,1)]];

    yt1=yt(lag+1:end,1);

    xt1=xt;    

sta=regstats(yt1,xt1);


res=sta.r;

est_yt=yt1-sta.r;


simu_all=[];

for boot=1:simu_round
    
     rd_index= randperm(size(res, 1)); 
     rdres = res(rd_index, :);
     
     rd_yt=est_yt+rdres;
    
     
      sta_rd=regstats(rd_yt,xt1);
     
     adjr2=sta_rd.adjrsquare;
     
    maxLag = floor(4*(35/100)^(2/9));

    [~,se,coeff] = hac(xt1,rd_yt,'bandwidth',maxLag+1,'display','off');


    t_nw=coeff./se;

    res_1_round=[coeff(end-3,1);t_nw(end-3,1);coeff(end-2,1);t_nw(end-2,1);
     coeff(end-1,1);t_nw(end-1,1);coeff(end,1);t_nw(end,1);adjr2];
   
     
     simu_all=[simu_all,res_1_round];
     
    
end

simu_all=simu_all';

simu_all=sortrows(simu_all,size(simu_all,2)-1);

simu_res5=simu_all(simu_bottom,:);

simu_res5=simu_res5';

%%%%%%%%%%%%%%%%%%%%

yt=bond_1y;
    
    lag=1;
    
    lagy=[];
    
    simu_round=5000;
    simu_bottom=simu_round*0.75;
    
    for i=1:lag
        
        
     lagy=[lagy,yt(i:size(yt,1)-lag-1+i)];
        
    end
    

    xt=[lagy,[ts(lag:size(yt,1)-lag-1+i,1),fr(lag:size(yt,1)-lag-1+i,1),dp(lag:size(yt,1)-lag-1+i,1),ndp(lag:size(yt,1)-lag-1+i,1)]];

    yt1=yt(lag+1:end,1);

    xt1=xt;    

sta=regstats(yt1,xt1);


res=sta.r;

est_yt=yt1-sta.r;


simu_all=[];

for boot=1:simu_round
    
     rd_index= randperm(size(res, 1)); 
     rdres = res(rd_index, :);
     
     rd_yt=est_yt+rdres;
    
     
      sta_rd=regstats(rd_yt,xt1);
     
     adjr2=sta_rd.adjrsquare;
     
    maxLag = floor(4*(35/100)^(2/9));

    [~,se,coeff] = hac(xt1,rd_yt,'bandwidth',maxLag+1,'display','off');


    t_nw=coeff./se;

    res_1_round=[coeff(end-3,1);t_nw(end-3,1);coeff(end-2,1);t_nw(end-2,1);
     coeff(end-1,1);t_nw(end-1,1);coeff(end,1);t_nw(end,1);adjr2];
   
     
     simu_all=[simu_all,res_1_round];
     
    
end

simu_all=simu_all';

simu_all=sortrows(simu_all,size(simu_all,2)-1);

simu_res6=simu_all(simu_bottom,:);

simu_res6=simu_res6';


%%%%%%%%%%%%%%%%%%%%%%

yt=loan_1y;
    
    lag=1;
    
    lagy=[];
    
    simu_round=5000;
    simu_bottom=simu_round*0.75;
    
    for i=1:lag
        
        
     lagy=[lagy,yt(i:size(yt,1)-lag-1+i)];
        
    end
    

    xt=[lagy,[ts(lag:size(yt,1)-lag-1+i,1),fr(lag:size(yt,1)-lag-1+i,1),dp(lag:size(yt,1)-lag-1+i,1),ndp(lag:size(yt,1)-lag-1+i,1)]];

    yt1=yt(lag+1:end,1);

    xt1=xt;    

sta=regstats(yt1,xt1);


res=sta.r;

est_yt=yt1-sta.r;


simu_all=[];

for boot=1:simu_round
    
     rd_index= randperm(size(res, 1)); 
     rdres = res(rd_index, :);
     
     rd_yt=est_yt+rdres;
    
     
      sta_rd=regstats(rd_yt,xt1);
     
     adjr2=sta_rd.adjrsquare;
     
    maxLag = floor(4*(35/100)^(2/9));

    [~,se,coeff] = hac(xt1,rd_yt,'bandwidth',maxLag+1,'display','off');


    t_nw=coeff./se;

    res_1_round=[coeff(end-3,1);t_nw(end-3,1);coeff(end-2,1);t_nw(end-2,1);
     coeff(end-1,1);t_nw(end-1,1);coeff(end,1);t_nw(end,1);adjr2];
   
     
     simu_all=[simu_all,res_1_round];
     
    
end

simu_all=simu_all';

simu_all=sortrows(simu_all,size(simu_all,2)-1);

simu_res7=simu_all(simu_bottom,:);

simu_res7=simu_res7';



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



yt=loan_1_5y;
    
    lag=1;
    
    lagy=[];
    
    simu_round=5000;
    simu_bottom=simu_round*0.75;
    
    for i=1:lag
        
        
     lagy=[lagy,yt(i:size(yt,1)-lag-1+i)];
        
    end
    

    xt=[lagy,[ts(lag:size(yt,1)-lag-1+i,1),fr(lag:size(yt,1)-lag-1+i,1),dp(lag:size(yt,1)-lag-1+i,1),ndp(lag:size(yt,1)-lag-1+i,1)]];

    yt1=yt(lag+1:end,1);

    xt1=xt;    

sta=regstats(yt1,xt1);


res=sta.r;

est_yt=yt1-sta.r;


simu_all=[];

for boot=1:simu_round
    
     rd_index= randperm(size(res, 1)); 
     rdres = res(rd_index, :);
     
     rd_yt=est_yt+rdres;
    
     
      sta_rd=regstats(rd_yt,xt1);
     
     adjr2=sta_rd.adjrsquare;
     
    maxLag = floor(4*(35/100)^(2/9));

    [~,se,coeff] = hac(xt1,rd_yt,'bandwidth',maxLag+1,'display','off');


    t_nw=coeff./se;

    res_1_round=[coeff(end-3,1);t_nw(end-3,1);coeff(end-2,1);t_nw(end-2,1);
     coeff(end-1,1);t_nw(end-1,1);coeff(end,1);t_nw(end,1);adjr2];
   
     
     simu_all=[simu_all,res_1_round];
     
    
end

simu_all=simu_all';

simu_all=sortrows(simu_all,size(simu_all,2)-1);

simu_res8=simu_all(simu_bottom,:);

simu_res8=simu_res8';


simu_res_final_B=[simu_res5,simu_res6,simu_res7,simu_res8];           % combine all results to get panel B of table A2





toc 
   
   
 